@@ -12,6 +12,7 @@
 #ifndef __XML_XPATH_INTERNALS_H__
 #define __XML_XPATH_INTERNALS_H__
 
+#include <stdio.h>
 #include <libxml/xmlversion.h>
 #include <libxml/xpath.h>
 
@@ -21,6 +22,12 @@
 extern "C" {
 #endif
 
+/*
+ * Backward compatibility
+ */
+#define valuePush xmlXPathValuePush
+#define valuePop xmlXPathValuePop
+
 /************************************************************************
  *									*
  *			Helpers						*
@@ -297,7 +304,7 @@ XMLPUBFUN void *
     if (ctxt == NULL) return;						\
     if (nargs != (x))							\
         XP_ERROR(XPATH_INVALID_ARITY);					\
-    if (ctxt->valueNr < ctxt->valueFrame + (x))				\
+    if (ctxt->valueNr < (x))						\
         XP_ERROR(XPATH_STACK_ERROR);
 
 /**
@@ -477,11 +484,10 @@ XMLPUBFUN xmlXPathParserContextPtr
 XMLPUBFUN void
 		xmlXPathFreeParserContext	(xmlXPathParserContextPtr ctxt);
 
-/* TODO: remap to xmlXPathValuePop and Push. */
 XMLPUBFUN xmlXPathObjectPtr
-		valuePop			(xmlXPathParserContextPtr ctxt);
+		xmlXPathValuePop		(xmlXPathParserContextPtr ctxt);
 XMLPUBFUN int
-		valuePush			(xmlXPathParserContextPtr ctxt,
+		xmlXPathValuePush		(xmlXPathParserContextPtr ctxt,
 						 xmlXPathObjectPtr value);
 
 XMLPUBFUN xmlXPathObjectPtr
@@ -515,6 +521,7 @@ XMLPUBFUN void
 
 XMLPUBFUN void
 		xmlXPathRoot			(xmlXPathParserContextPtr ctxt);
+XML_DEPRECATED
 XMLPUBFUN void
 		xmlXPathEvalExpr		(xmlXPathParserContextPtr ctxt);
 XMLPUBFUN xmlChar *
